@@ -2,12 +2,13 @@ import lab as B
 from algebra import proven
 from wbml.warning import warn_upmodule
 
+from .util import align_batch
 from ..constant import Constant, Zero
 from ..diagonal import Diagonal
 from ..kronecker import Kronecker
 from ..lowrank import LowRank
 from ..matrix import AbstractMatrix, Dense, structured
-from ..shape import assert_compatible, broadcast
+from ..shape import assert_compatible
 from ..triangular import LowerTriangular, UpperTriangular
 from ..util import ToDenseWarning, redirect
 from ..woodbury import Woodbury
@@ -26,14 +27,14 @@ def _reverse_call(t0, t1):
 
 @B.dispatch(precedence=proven())
 def multiply(a: AbstractMatrix, b: Zero):
-    assert_compatible(a, b)
-    return B.broadcast_to(b, *broadcast(a, b).as_tuple())
+    assert_compatible(B.shape(a), B.shape(b))
+    return B.broadcast_to(b, *B.shape_broadcast(a, b))
 
 
 @B.dispatch(precedence=proven())
 def multiply(a: Zero, b: AbstractMatrix):
-    assert_compatible(a, b)
-    return B.broadcast_to(a, *broadcast(a, b).as_tuple())
+    assert_compatible(B.shape(a), B.shape(b))
+    return B.broadcast_to(a, *B.shape_broadcast(a, b))
 
 
 # Dense
@@ -63,13 +64,18 @@ def multiply(a: Diagonal, b: Diagonal):
 
 @B.dispatch
 def multiply(a: Diagonal, b: AbstractMatrix):
-    assert_compatible(a, b)
-    # In the case of broadcasting, `B.diag(b)` will not get the diagonal of the
-    # broadcasted version of `b`, so we exercise extra caution in that case.
-    rows, cols = B.shape(b)
-    if rows == 1 or cols == 1:
-        b_diag = B.squeeze(B.dense(b))
+    assert_compatible(B.shape(a), B.shape(b))
+    # In the case of broadcasting, `B.diag(b)` will get the diagonal of `b`, which may
+    # not be equalt to the diagonal broadcasted version of `b`.
+    rows, cols = B.shape_matrix(b)
+    if rows == 1:
+        # Due to broadcasting, the diagonal will be the one column.
+        b_diag = B.squeeze(B.dense(b), axis=-2)
+    elif cols == 1:
+        # Due to broadcasting, the diagonal will be the one row.
+        b_diag = B.squeeze(B.dense(b), axis=-1)
     else:
+        # No broadcasting happening. Just get the diagonal.
         b_diag = B.diag(b)
     return Diagonal(B.multiply(a.diag, b_diag))
 
@@ -82,26 +88,34 @@ _reverse_call(Diagonal, AbstractMatrix)
 
 @B.dispatch
 def multiply(a: Constant, b: Constant):
-    assert_compatible(a, b)
-    return Constant(B.multiply(a.const, b.const), *broadcast(a, b).as_tuple())
+    assert_compatible(B.shape(a), B.shape(b))
+    return Constant(B.multiply(a.const, b.const), *B.shape_broadcast(a, b))
 
 
 @B.dispatch
 def multiply(a: Constant, b: AbstractMatrix):
-    assert_compatible(a, b)
+    assert_compatible(B.shape(a), B.shape(b))
     if structured(b):
         warn_upmodule(
             f"Multiplying {a} and {b}: converting to dense.", category=ToDenseWarning
         )
     return Dense(
-        B.broadcast_to(B.multiply(a.const, B.dense(b)), *broadcast(a, b).as_tuple())
+        B.broadcast_to(
+            B.multiply(
+                B.expand_dims(a.const, axis=-1, times=2, ignore_scalar=True),
+                B.dense(b),
+            ),
+            *B.shape_broadcast(a, b),
+        )
     )
 
 
 @B.dispatch
 def multiply(a: Constant, b: Diagonal):
-    assert_compatible(a, b)
-    return Diagonal(B.multiply(a.const, b.diag))
+    assert_compatible(B.shape(a), B.shape(b))
+    return Diagonal(
+        B.multiply(B.expand_dims(a.const, axis=-1, ignore_scalar=True), b.diag)
+    )
 
 
 _reverse_call(Constant, AbstractMatrix)
@@ -124,7 +138,9 @@ def multiply(a: LowerTriangular, b: AbstractMatrix):
 
 @B.dispatch
 def multiply(a: LowerTriangular, b: Constant):
-    return LowerTriangular(B.multiply(a.mat, b.const))
+    return LowerTriangular(
+        B.multiply(a.mat, B.expand_dims(b.const, axis=-1, times=2, ignore_scalar=True))
+    )
 
 
 _reverse_call(LowerTriangular, AbstractMatrix)
@@ -149,12 +165,14 @@ def multiply(a: UpperTriangular, b: LowerTriangular):
 @B.dispatch
 def multiply(a: UpperTriangular, b: AbstractMatrix):
     # TODO: Optimise away `B.dense` call.
-    return UpperTriangular(a.mat * B.dense(b))
+    return UpperTriangular(B.multiply(a.mat, B.dense(b)))
 
 
 @B.dispatch
 def multiply(a: UpperTriangular, b: Constant):
-    return UpperTriangular(B.multiply(a.mat, b.const))
+    return UpperTriangular(
+        B.multiply(a.mat, B.expand_dims(b.const, axis=-1, times=2, ignore_scalar=True))
+    )
 
 
 _reverse_call(UpperTriangular, LowerTriangular)
@@ -169,7 +187,7 @@ redirect(B.multiply, (UpperTriangular, Diagonal), (AbstractMatrix, Diagonal))
 
 @B.dispatch
 def multiply(a: LowRank, b: LowRank):
-    assert_compatible(a, b)
+    assert_compatible(B.shape(a), B.shape(b))
 
     if structured(a.left, a.right, b.left, b.right):
         warn_upmodule(
@@ -179,22 +197,32 @@ def multiply(a: LowRank, b: LowRank):
     al, am, ar = B.dense(a.left), B.dense(a.middle), B.dense(a.right)
     bl, bm, br = B.dense(b.left), B.dense(b.middle), B.dense(b.right)
 
+    # Perform broadcasting of batch dimensions.
+    al, am, ar, bl, bm, br = align_batch(al, am, ar, bl, bm, br)
+    offset = len(B.shape_batch(al))
+
     # Pick apart the matrices.
-    al, ar = B.unstack(al, axis=1), B.unstack(ar, axis=1)
-    bl, br = B.unstack(bl, axis=1), B.unstack(br, axis=1)
-    am = [B.unstack(x, axis=0) for x in B.unstack(am, axis=0)]
-    bm = [B.unstack(x, axis=0) for x in B.unstack(bm, axis=0)]
+    al, ar = B.unstack(al, axis=offset + 1), B.unstack(ar, axis=offset + 1)
+    bl, br = B.unstack(bl, axis=offset + 1), B.unstack(br, axis=offset + 1)
+    am = [B.unstack(x, axis=offset) for x in B.unstack(am, axis=offset)]
+    bm = [B.unstack(x, axis=offset) for x in B.unstack(bm, axis=offset)]
 
     # Construct the factors.
-    left = B.stack(*[B.multiply(ali, blk) for ali in al for blk in bl], axis=1)
-    right = B.stack(*[B.multiply(arj, brl) for arj in ar for brl in br], axis=1)
+    left = B.stack(
+        *[B.multiply(ali, blk) for ali in al for blk in bl],
+        axis=offset + 1,
+    )
+    right = B.stack(
+        *[B.multiply(arj, brl) for arj in ar for brl in br],
+        axis=offset + 1,
+    )
     middle = B.stack(
         *[
-            B.stack(*[amij * bmkl for amij in ami for bmkl in bmk], axis=0)
+            B.stack(*[amij * bmkl for amij in ami for bmkl in bmk], axis=offset)
             for ami in am
             for bmk in bm
         ],
-        axis=0,
+        axis=offset,
     )
 
     return LowRank(left, right, middle)
@@ -202,8 +230,15 @@ def multiply(a: LowRank, b: LowRank):
 
 @B.dispatch
 def multiply(a: Constant, b: LowRank):
-    assert_compatible(a, b)
-    return LowRank(b.left, b.right, B.multiply(a.const, b.middle))
+    assert_compatible(B.shape(a), B.shape(b))
+    return LowRank(
+        b.left,
+        b.right,
+        B.multiply(
+            B.expand_dims(a.const, axis=-1, times=2, ignore_scalar=True),
+            b.middle,
+        ),
+    )
 
 
 @B.dispatch
@@ -237,20 +272,24 @@ redirect(B.multiply, (Woodbury, UpperTriangular), (Woodbury, AbstractMatrix))
 
 @B.dispatch
 def multiply(a: Kronecker, b: Kronecker):
-    left_compatible = B.shape(a.left) == B.shape(b.left)
-    right_compatible = B.shape(a.right) == B.shape(b.right)
+    left_compatible = B.shape_matrix(a.left) == B.shape_matrix(b.left)
+    right_compatible = B.shape_matrix(a.right) == B.shape_matrix(b.right)
     if not (left_compatible and right_compatible):
         raise AssertionError(
-            f"Factors of Kronecker products {a} and {b} must be compatible, "
-            f"but they are not."
+            f"Kronecker products {a} and {b} must be compatible, but they are not."
         )
     return Kronecker(B.multiply(a.left, b.left), B.multiply(a.right, b.right))
 
 
 @B.dispatch
 def multiply(a: Constant, b: Kronecker):
-    assert_compatible(a, b)
-    return Kronecker(B.multiply(a.const, b.left), b.right)
+    assert_compatible(B.shape(a), B.shape(b))
+    return Kronecker(
+        B.multiply(
+            B.expand_dims(a.const, axis=-1, times=2, ignore_scalar=True), b.left
+        ),
+        b.right,
+    )
 
 
 @B.dispatch
