@@ -1,7 +1,7 @@
 import lab as B
 from wbml.warning import warn_upmodule
 
-from ..constant import Zero, Constant
+from ..constant import Constant, Zero
 from ..diagonal import Diagonal
 from ..kronecker import Kronecker
 from ..matrix import AbstractMatrix, Dense, structured
@@ -48,4 +48,4 @@ def power(a: UpperTriangular, b: B.Numeric):
 
 @B.dispatch
 def power(a: Kronecker, b: B.Numeric):
-    return Kronecker(B.power(a.left, b), B.power(a.right, b))
\ No newline at end of file
+    return Kronecker(B.power(a.left, b), B.power(a.right, b))
