@@ -1,14 +1,10 @@
 import lab as B
-from algebra import proven
 
 from ..matrix import AbstractMatrix
 
 __all__ = []
 
 
-# Zero
-
-
-@B.dispatch(precedence=proven())
+@B.dispatch
 def subtract(a: AbstractMatrix, b: AbstractMatrix):
     return B.add(a, B.negative(b))
