@@ -13,21 +13,19 @@ add_promotion_rule(AbstractMatrix, AbstractMatrix, AbstractMatrix)
 
 @conversion_method(B.Numeric, AbstractMatrix)
 def convert(x):
-    if B.rank(x) == 0:
+    if B.is_scalar(x):
         if isinstance(x, B.Number) and x == 0:
             return Zero(B.dtype(x), 1, 1)
         else:
             return Constant(x, 1, 1)
-    elif B.rank(x) == 2:
-        return Dense(x)
     else:
-        raise RuntimeError(f"Cannot convert rank {B.rank(x)} input to a matrix.")
+        return Dense(x)
 
 
 @conversion_method(Constant, LowRank)
 def constant_to_lowrank(a):
     dtype = B.dtype(a)
-    rows, cols = B.shape(a)
+    rows, cols = B.shape_matrix(a)
     middle = B.fill_diag(a.const, 1)
     if rows == cols:
         return LowRank(B.ones(dtype, rows, 1), middle=middle)
