@@ -1,7 +1,7 @@
 import lab as B
 
 # noinspection PyUnresolvedReferences
-from ..util import approx, check_un_op, AssertDenseWarning, dense1, diag1
+from ..util import AssertDenseWarning, approx, check_un_op, dense1, diag1
 
 
 def test_take_dense(dense1):
