@@ -7,13 +7,15 @@ def test_kronecker_formatting():
     left = Diagonal(B.ones(2))
     right = Diagonal(B.ones(3))
     assert (
-        str(Kronecker(left, right)) == "<Kronecker product: shape=6x6, dtype=float64>"
+        str(Kronecker(left, right)) == ""
+        "<Kronecker product: batch=(), shape=(6, 6), dtype=float64>"
     )
     assert (
-        repr(Kronecker(left, right)) == "<Kronecker product: shape=6x6, dtype=float64\n"
-        " left=<diagonal matrix: shape=2x2, dtype=float64\n"
+        repr(Kronecker(left, right)) == ""
+        "<Kronecker product: batch=(), shape=(6, 6), dtype=float64\n"
+        " left=<diagonal matrix: batch=(), shape=(2, 2), dtype=float64\n"
         "       diag=[1. 1.]>\n"
-        " right=<diagonal matrix: shape=3x3, dtype=float64\n"
+        " right=<diagonal matrix: batch=(), shape=(3, 3), dtype=float64\n"
         "        diag=[1. 1. 1.]>>"
     )
 
